@@ -14,12 +14,11 @@
 ##' @author Klaus K. Holst
 ##' @examples
 ##' set.seed(1)
-##' d <- subset(simClaytonOakes(500,4,2,1,stoptime=2,left=2),!truncated)
+##' d <- subset(simClaytonOakes(500,4,2,1,stoptime=2,left=2),truncated)
 ##' e <- ClaytonOakes(survival::Surv(lefttime,time,status)~x+cluster(~1,cluster),
 ##'                   cuts=c(0,0.5,1,2),data=d)
 ##' e
-##' 
-##' 
+##'
 ##' d2 <- simClaytonOakes(500,4,2,1,stoptime=2,left=0)
 ##' d2$z <- rep(1,nrow(d2)); d2$z[d2$cluster%in%sample(d2$cluster,100)] <- 0
 ##' ## Marginal=Cox Proportional Hazards model:
@@ -32,9 +31,15 @@
 ##' e2 <- ClaytonOakes(survival::Surv(time,status)~x+cluster(~-1+factor(z),cluster),
 ##'                    cuts=c(0,0.5,1,2),data=d2)
 ##' e2
-##' plot(ts)
-##' plot(e2,add=TRUE)
-##' 
+##'
+##'
+##' e0 <- ClaytonOakes(survival::Surv(time,status)~cluster(~-1+factor(z),cluster),
+##'                    cuts=c(0,0.5,1,2),data=d2)
+##' ts0 <- ClaytonOakes(survival::Surv(time,status)~cluster(~1,cluster),
+##'                    data=d2,type="two.stage")
+##' plot(ts0)
+##' plot(e0,add=TRUE)
+##'
 ##' e3 <- ClaytonOakes(survival::Surv(time,status)~x+cluster(~1,cluster),cuts=c(0,0.5,1,2),
 ##'                    data=d,var.invlink=identity)
 ##' e3
@@ -73,6 +78,7 @@ ClaytonOakes <- function(formula,data=parent.frame(),cluster,var.formula=~1,cuts
 
   if (type!="piecewise") {
     timeregmod <- ifelse(length(formulaProp)>0,"cox.aalen","aalen")
+    timeregmod <- get(timeregmod, asNamespace("timereg"))
     if (is.null(dots$robust)) dots$robust <- 0
     args <- c(list(formula=formula,data=data,max.clust=NULL,clusters=data[,cluster]),dots)
     marg <- do.call(timeregmod, args)    
@@ -145,8 +151,8 @@ ClaytonOakes <- function(formula,data=parent.frame(),cluster,var.formula=~1,cuts
     res <- .Call("claytonoakes",
            ds=mydata$status,ts=mydata$T,es=mydata$entry,
            allcs=mydata$cluster,cs=ucluster, cuts=cuts,
-                 hs=exp(p),mulths=multhaz,
-                 var=theta0)$logLik    
+           hs=exp(p),mulths=multhaz,
+           var=theta0,PACKAGE="mets")$logLik    
     return(-res)
   }
   opt <- tryCatch(nlminb(p0,obj,control=control),error=function(x) NULL)
